﻿using System;
using System.Net;
using System.Security;
using System.Windows;
using Ecng.Common;
using StockSharp.Algo;
using StockSharp.Algo.Candles;
using StockSharp.BusinessEntities;
using StockSharp.Xaml.Charting;
using StockSharp.Quik;
using Ecng.Xaml;

namespace ShowChart
{
    /// <summary>
    /// Логика взаимодействия для MainWindow.xaml
    /// </summary>
    public partial class MainWindow : Window
    {
        private QuikTrader _trader;
        private Security _security;
        public static CandleManager CandleManager { get; private set; }
        public static CandleSeries Series { get; private set; }
        public Portfolio Portfolio { get; private set; }
        public CandleSeries CandleSeries { get; private set; }
        public MyStrategy MyStrategy;
        public static MainWindow Oder;

        public MainWindow()
        {
            InitializeComponent();
            Chart.AddArea(new ChartArea());
            Loaded += MainWindow_Loaded;
            Oder = this;
        }

        private void MainWindow_Loaded(object sender, RoutedEventArgs e)
        {
            _trader = new QuikTrader()
            {
                LuaLogin = "Quik",
                LuaPassword = "Quik".To<SecureString>(),
                LuaFixServerAddress = "127.0.0.1:5001".To<EndPoint>(),
            };

            _trader.NewSecurity += security =>
            {
                if (security.Code == "SBER")
                {
                    _security = security;
                    Console.WriteLine("Инструмент получен!");
                    Start();
                }
            };
            _trader.NewPortfolio += portfolio =>
            {
                if (portfolio.Name == "NL0011100043") {Portfolio = portfolio; Start();}
            };
            _trader.Connect();
        }

        private void Start()
        {
            if (_security == null || Portfolio == null) return;
            MyStrategy = new MyStrategy();
            MyStrategy.Connector = _trader;
            MyStrategy.Security = _security;
            MyStrategy.ChartPanel = Chart;
            MyStrategy.Portfolio = Portfolio;
            if(MyStrategy.CandleManager == null) MyStrategy.CandleManager = new CandleManager((QuikTrader)_trader);
            if (MyStrategy.CandleSeries == null) MyStrategy.CandleSeries = new CandleSeries(typeof(TimeFrameCandle), _security, TimeSpan.FromMinutes(1));

            this.GuiAsync(()=> StartButton.IsEnabled = StopButton.IsEnabled = Portfolio != null && _security != null);
        }

        private void StartButton_Click(object sender, RoutedEventArgs e)
        {
            MyStrategy.Start();
            MyStrategy.CandleManager.Start(MyStrategy.CandleSeries);
        }

        private void StopButton_Click(object sender, RoutedEventArgs e)
        {
            MyStrategy.Stop();
            MyStrategy.CandleManager.Stop(MyStrategy.CandleSeries);
            MyStrategy.InitCart();
        }
    }
}
